# flipnote.py
A Python library for Flipnote Studio (3D) files.

This is based on [kwz-parser](https://github.com/Flipnote-Collective/kwz-parser) and 
[ppm-parser](https://github.com/Flipnote-Collective/ppm-parser) by the flipnote collective.
